@@ -1,11 +1,11 @@
 import ast
 import json
-import warnings
 from contextlib import contextmanager
 
 from airflow.exceptions import AirflowException, AirflowSkipException
 from dagster import check, seven
-from dagster.cli.api import StepExecutionSkipped
+from dagster.core.execution.api import create_execution_plan
+from dagster.core.execution.plan.plan import should_skip_step
 from dagster.core.instance import AIRFLOW_EXECUTION_DATE_STR, DagsterInstance
 from dagster.grpc.types import ExecuteStepArgs
 from dagster.serdes import deserialize_json_to_dagster_namedtuple, serialize_dagster_namedtuple
@@ -40,52 +40,8 @@ class DagsterDockerOperator(DockerOperator):
         tmp_dir = kwargs.pop("tmp_dir", DOCKER_TEMPDIR)
         host_tmp_dir = kwargs.pop("host_tmp_dir", seven.get_system_temp_directory())
         self.host_tmp_dir = host_tmp_dir
-
-        run_config = dagster_operator_parameters.run_config
-        if "filesystem" in run_config["intermediate_storage"]:
-            if (
-                "config" in (run_config["intermediate_storage"].get("filesystem", {}) or {})
-                and "base_dir"
-                in (
-                    (run_config["intermediate_storage"].get("filesystem", {}) or {}).get(
-                        "config", {}
-                    )
-                    or {}
-                )
-                and run_config["intermediate_storage"]["filesystem"]["config"]["base_dir"]
-                != tmp_dir
-            ):
-                warnings.warn(
-                    "Found base_dir '{base_dir}' set in filesystem storage config, which was not "
-                    "the tmp_dir we expected ('{tmp_dir}', mounting host_tmp_dir "
-                    "'{host_tmp_dir}' from the host). We assume you know what you are doing, but "
-                    "if you are having trouble executing containerized workloads, this may be the "
-                    "issue".format(
-                        base_dir=run_config["intermediate_storage"]["filesystem"]["config"][
-                            "base_dir"
-                        ],
-                        tmp_dir=tmp_dir,
-                        host_tmp_dir=host_tmp_dir,
-                    )
-                )
-            else:
-                run_config["intermediate_storage"]["filesystem"] = dict(
-                    run_config["intermediate_storage"]["filesystem"] or {},
-                    **{
-                        "config": dict(
-                            (
-                                (
-                                    run_config["intermediate_storage"].get("filesystem", {}) or {}
-                                ).get("config", {})
-                                or {}
-                            ),
-                            **{"base_dir": tmp_dir},
-                        )
-                    },
-                )
-
         self.docker_conn_id_set = kwargs.get("docker_conn_id") is not None
-        self.run_config = run_config
+        self.run_config = dagster_operator_parameters.run_config
         self.pipeline_name = dagster_operator_parameters.pipeline_name
         self.pipeline_snapshot = dagster_operator_parameters.pipeline_snapshot
         self.execution_plan_snapshot = dagster_operator_parameters.execution_plan_snapshot
@@ -183,9 +139,12 @@ class DagsterDockerOperator(DockerOperator):
 
             result = self.cli.wait(self.container["Id"])
             if result["StatusCode"] != 0:
+                full_logs = self.cli.logs(container=self.container["Id"], stdout=True, stderr=True)
+
                 raise AirflowException(
                     "docker container failed with result: {result} and logs: {logs}".format(
-                        result=repr(result), logs="\n".join(res)
+                        result=repr(result),
+                        logs=full_logs,
                     )
                 )
 
@@ -247,6 +206,18 @@ class DagsterDockerOperator(DockerOperator):
 
         return _DummyHook()
 
+    def _should_skip(self, pipeline_run):
+        recon_pipeline = self.recon_repo.get_reconstructable_pipeline(self.pipeline_name)
+        execution_plan = create_execution_plan(
+            recon_pipeline.subset_for_execution_from_existing_pipeline(
+                pipeline_run.solids_to_execute
+            ),
+            run_config=self.run_config,
+            step_keys_to_execute=self.step_keys,
+            mode=self.mode,
+        )
+        return should_skip_step(execution_plan, instance=self.instance, run_id=pipeline_run.run_id)
+
     def execute(self, context):
         if "run_id" in self.params:
             self._run_id = self.params["run_id"]
@@ -256,7 +227,7 @@ class DagsterDockerOperator(DockerOperator):
         try:
             tags = {AIRFLOW_EXECUTION_DATE_STR: context.get("ts")} if "ts" in context else {}
 
-            self.instance.register_managed_run(
+            pipeline_run = self.instance.register_managed_run(
                 pipeline_name=self.pipeline_name,
                 run_id=self.run_id,
                 run_config=self.run_config,
@@ -270,6 +241,10 @@ class DagsterDockerOperator(DockerOperator):
                 execution_plan_snapshot=self.execution_plan_snapshot,
                 parent_pipeline_snapshot=self.parent_pipeline_snapshot,
             )
+            if self._should_skip(pipeline_run):
+                raise AirflowSkipException(
+                    "Dagster emitted skip event, skipping execution in Airflow"
+                )
 
             res = self.execute_raw(context)
             self.log.info("Finished executing container.")
@@ -285,11 +260,6 @@ class DagsterDockerOperator(DockerOperator):
                     "Could not parse response {response}".format(response=repr(res))
                 )
 
-            if len(events) == 1 and isinstance(events[0], StepExecutionSkipped):
-                raise AirflowSkipException(
-                    "Dagster emitted skip event, skipping execution in Airflow"
-                )
-
             check_events_for_failures(events)
             check_events_for_skips(events)
 
